RawSocketOptionMixin mixin

class MyRawSocketOption with RawSocketOptionMixin implements RawSocketOption { 
  // Must override 
  @override 
  RawSocketOption get rawSocketOption;
  ...
}
Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
level int
The level for the option to set or get.
no setteroverride
option int
The numeric ID of the option to set or get.
no setteroverride
rawSocketOption RawSocketOption
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value Uint8List
The raw data to set, or the array to write the current option value into.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited